###########################
Useful Command Combinations
###########################

As mentioned previously, there are some shortcuts commands
that perform the action of two or more other commands.

- One combination copies the current Fact metadata and pastes it to the final Fact.

  - Mapped to ``Ctrl-e`` by default.

- A similar combination copies the current Fact metadata, but stops the final Fact,
  and applies the metadata to the new active Fact.

  - Mapped to ``V`` by default.

There's also a combination command to start a new Fact and prompt you for the
activity and category, which can be called from anywhere.

- This command stops the final Fact, switches to the new active Fact,
  and prompts you for the act\@gory.

  - Mapped to ``o`` by default.

If you can think of other useful combinations, please tell us, or submit a
pull request.

